@@ -2,6 +2,4 @@
 
 from .csv import csv_to_pandas
 
-__all__ = [
-    'csv_to_pandas'
-] 
\ No newline at end of file
+__all__ = ["csv_to_pandas"]
