@@ -1,9 +1,6 @@
 """Repository and directory loaders."""
 
-from .git import git_repo_to_structure
 from .directories import directory_to_structure
+from .git import git_repo_to_structure
 
-__all__ = [
-    'git_repo_to_structure',
-    'directory_to_structure'
-] 
\ No newline at end of file
+__all__ = ["git_repo_to_structure", "directory_to_structure"]
