@@ -2,8 +2,4 @@
 
 from .urls import url_to_bs4, url_to_file, url_to_response
 
-__all__ = [
-    'url_to_bs4',
-    'url_to_file',
-    'url_to_response'
-] 
\ No newline at end of file
+__all__ = ["url_to_bs4", "url_to_file", "url_to_response"]
