@@ -2,6 +2,4 @@
 
 from .images import *
 
-__all__ = [
-    'images'
-] 
\ No newline at end of file
+__all__ = ["images"]
