@@ -1,12 +1,11 @@
 from attachments import attach, load, present
 
+
 def test_excel_to_csv():
     """Ensure LibreOffice-based CSV extraction works and returns the expected rows."""
     xlsx = "src/attachments/data/test_workbook.xlsx"
 
-    att = (attach(f"{xlsx}[format:csv]")
-           | load.excel_to_libreoffice
-           | present.csv)
+    att = attach(f"{xlsx}[format:csv]") | load.excel_to_libreoffice | present.csv
 
     csv_text = str(att)
 
@@ -17,4 +16,4 @@ def test_excel_to_csv():
     assert "Widget A,1000,North" in csv_text
     assert "Widget B,1500,South" in csv_text
     # No LibreOffice conversion error
-    assert att.metadata.get("libreoffice_error") is None
\ No newline at end of file
+    assert att.metadata.get("libreoffice_error") is None
